@@ -1,8 +1,8 @@
 ;;;============================================================================
 
-;;; File: "_io#.scm", Time-stamp: <2009-11-24 19:11:32 feeley>
+;;; File: "_io#.scm"
 
-;;; Copyright (c) 1994-2009 by Marc Feeley, All Rights Reserved.
+;;; Copyright (c) 1994-2013 by Marc Feeley, All Rights Reserved.
 
 ;;;============================================================================
 
@@ -121,6 +121,7 @@
   wtimeout           ;; time at which a write that would block times out
   wtimeout-thunk     ;; thunk called when a write timeout occurs
   set-wtimeout       ;; procedure to set wtimeout and wtimeout-thunk
+  io-exception-handler ;; procedure to handle I/O exceptions on this port
 )
 
 (define-check-type port (macro-type-port)
@@ -948,6 +949,7 @@
   labels
   container
   filepos
+  read-cont ;; the continuation of the read procedure
 )
 
 (##define-macro (macro-readenv-wrap re x)
@@ -1124,6 +1126,7 @@
   (r6rs-compatible-read?          unprintable: read-write:)
   (r6rs-compatible-write?         unprintable: read-write:)
   (here-strings-allowed?          unprintable: read-write:)
+  (comment-handler                unprintable: read-write:)
 )
 
 (define-check-type readtable (macro-type-readtable)
